/*******************************************************************************
 * Copyright (c) 2000, 2008 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.jdt.internal.core.manipulation;

/**
 * Defines status codes relevant to the Java Manipulation plug-in.
  */
public interface IStatusConstants {

	// Java Manipulation status constants start at 10000 to make sure that we don't
	// collide with resource and java model constants.

	int INTERNAL_ERROR= 10001;

 }
